==> haskell-adjunctions-4.4-294-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-adjunctions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 adjunctions
version:              4.4
visibility:           public
id:                   adjunctions-4.4-8Zdv5MirbpkDSRwYqFREuR
key:                  adjunctions-4.4-8Zdv5MirbpkDSRwYqFREuR
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2014 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/adjunctions/
synopsis:             Adjunctions and representable functors
description:          Adjunctions and representable functors.
category:             Data Structures, Adjunctions
abi:                  bb6e809fa6e3d67fc772f49777d2a4e2
exposed:              True
exposed-modules:
    Control.Comonad.Representable.Store Control.Comonad.Trans.Adjoint
    Control.Monad.Representable.Reader
    Control.Monad.Representable.State Control.Monad.Trans.Adjoint
    Control.Monad.Trans.Contravariant.Adjoint Control.Monad.Trans.Conts
    Data.Functor.Adjunction Data.Functor.Contravariant.Adjunction
    Data.Functor.Contravariant.Rep Data.Functor.Rep

import-dirs:          /usr/lib/ghc-9.0.2/site-local/adjunctions-4.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/adjunctions-4.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/adjunctions-4.4
hs-libraries:         HSadjunctions-4.4-8Zdv5MirbpkDSRwYqFREuR
depends:
    array-0.5.4.0 base-4.15.1.0 comonad-5.0.8-G2zswagKHSZ1M0oTcaWMsJ
    containers-0.6.4.1 contravariant-1.5.5-FtJyCLyWfutGN2UWoJs8qd
    distributive-0.6.2.1-6U9gj50rm92KnA1IP4blPZ
    free-5.1.7-AupsMtKhyL2K7uRgeDDY2h mtl-2.2.2
    profunctors-5.6.2-9ZMLCv2ea2EDiDd4QZEGt
    semigroupoids-5.3.7-8yviMqArY5qIcsmr8muRdj
    tagged-0.8.6.1-79gYUUazit6EfoPS33FHdR transformers-0.5.6.2
    transformers-compat-0.7.1-5G5J9BcZIFIGkjABObiUpP
    void-0.7.3-BXIeD8PDyVa6FzS0UDPl2

haddock-interfaces:   /usr/share/doc/haskell-adjunctions/html/adjunctions.haddock
haddock-html:         /usr/share/doc/haskell-adjunctions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-adjunctions-4.4-304-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-adjunctions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 adjunctions
version:              4.4
visibility:           public
id:                   adjunctions-4.4-KIshoC7T2Xm6unrUYLcI7D
key:                  adjunctions-4.4-KIshoC7T2Xm6unrUYLcI7D
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2014 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/adjunctions/
synopsis:             Adjunctions and representable functors
description:          Adjunctions and representable functors.
category:             Data Structures, Adjunctions
abi:                  c6d1e64409612b6b03937891c83524f8
exposed:              True
exposed-modules:
    Control.Comonad.Representable.Store Control.Comonad.Trans.Adjoint
    Control.Monad.Representable.Reader
    Control.Monad.Representable.State Control.Monad.Trans.Adjoint
    Control.Monad.Trans.Contravariant.Adjoint Control.Monad.Trans.Conts
    Data.Functor.Adjunction Data.Functor.Contravariant.Adjunction
    Data.Functor.Contravariant.Rep Data.Functor.Rep

import-dirs:          /usr/lib/ghc-9.0.2/site-local/adjunctions-4.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/adjunctions-4.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-adjunctions
hs-libraries:         HSadjunctions-4.4-KIshoC7T2Xm6unrUYLcI7D
depends:
    array-0.5.4.0 base-4.15.1.0 comonad-5.0.8-1UV6j1oVRx49AwFFLVzzvh
    containers-0.6.4.1 contravariant-1.5.5-FtJyCLyWfutGN2UWoJs8qd
    distributive-0.6.2.1-CeMrxaxhyMt37Xl63aBbG2
    free-5.1.7-HLCs0Omc9ecAaipeGV9WC9 mtl-2.2.2
    profunctors-5.6.2-JxFhlDyh97VHS9KOg8R2VY
    semigroupoids-5.3.7-LNx6FZQ6yl1Ls9mIgv9Bbs
    tagged-0.8.6.1-79gYUUazit6EfoPS33FHdR transformers-0.5.6.2
    transformers-compat-0.7.1-5G5J9BcZIFIGkjABObiUpP
    void-0.7.3-BXIeD8PDyVa6FzS0UDPl2

haddock-interfaces:   /usr/share/doc/haskell-adjunctions/html/adjunctions.haddock
haddock-html:         /usr/share/doc/haskell-adjunctions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
